@@ -29,10 +29,10 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QSet>
+#include <QDebug>
 
 #include <KGamePopupItem>
-#include <KLocale>
-#include <KDebug>
+#include <KLocalizedString>
 
 inline uint qHash( const FieldPos& pos )
 {
@@ -45,11 +45,11 @@ KLinesScene::KLinesScene( QObject* parent )
       m_score(0), m_bonusScore(0), m_cellSize(32), m_previewZoneVisible(true)
 {
     m_animator = new KLinesAnimator(this);
-    connect( m_animator, SIGNAL(moveFinished()), SLOT(moveAnimFinished()) );
-    connect( m_animator, SIGNAL(removeFinished()), SLOT(removeAnimFinished()) );
-    connect( m_animator, SIGNAL(bornFinished()), SLOT(bornAnimFinished()) );
+    connect(m_animator, &KLinesAnimator::moveFinished, this, &KLinesScene::moveAnimFinished);
+    connect(m_animator, &KLinesAnimator::removeFinished, this, &KLinesScene::removeAnimFinished);
+    connect(m_animator, &KLinesAnimator::bornFinished, this, &KLinesScene::bornAnimFinished);
 
-    m_focusItem = new QGraphicsRectItem( QRectF(0, 0, m_cellSize, m_cellSize), 0, this );
+    m_focusItem = new QGraphicsRectItem( QRectF(0, 0, m_cellSize, m_cellSize), 0);
     m_focusItem->setZValue(1.0);
     m_focusItem->setPen( Qt::DashLine );
 
@@ -105,7 +105,7 @@ void KLinesScene::startNewGame()
         m_nextColors.append(c);
     }
 
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    emit stateChanged(QStringLiteral( "not_undoable" ));
 
     nextThreeBalls();
 }
@@ -172,7 +172,7 @@ void KLinesScene::resizeScene(int width,int height)
     m_previewItem->setPos( previewOriginX, previewOriginY );
     m_previewItem->setPreviewColors( m_nextColors );
 
-    //kDebug() << "resize:" << width << "," << height << "; cellSize:" << m_cellSize;
+    //qDebug() << "resize:" << width << "," << height << "; cellSize:" << m_cellSize;
 }
 
 void KLinesScene::endTurn()
@@ -600,7 +600,7 @@ void KLinesScene::saveUndoInfo()
     m_undoInfo.score = m_score;
     m_undoInfo.nextColors = m_nextColors;
 
-    emit stateChanged(QLatin1String( "undoable" ));
+    emit stateChanged(QStringLiteral( "undoable" ));
 }
 
 // Brings m_field and some other vars to the state it was before last turn
@@ -655,7 +655,7 @@ void KLinesScene::undo()
 
     emit scoreChanged(m_score);
 
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    emit stateChanged(QStringLiteral( "not_undoable" ));
 }
 
 void KLinesScene::drawBackground(QPainter *p, const QRectF&)
@@ -680,8 +680,8 @@ void KLinesScene::gameOverHandler()
     if( m_gameOver )
         return; // don't emit twice
     m_gameOver = true;
-    kDebug() << "GAME OVER";
-    emit stateChanged(QLatin1String( "not_undoable" ));
+    qDebug() << "GAME OVER";
+    emit stateChanged(QStringLiteral( "not_undoable" ));
     //emit enableUndo(false);
     emit gameOver(m_score);
 
@@ -690,4 +690,4 @@ void KLinesScene::gameOverHandler()
     m_popupItem->showMessage(i18n("<h1>Game over</h1>"), KGamePopupItem::Center);
 }
 
-#include "scene.moc"
+
